﻿<%@ Page Title="Google PageSpeed Test" Theme="Default" Language="C#" MasterPageFile="~/CMSMasterPages/UI/SimplePage.master" AutoEventWireup="true" CodeBehind="GooglePageSpeedTest.aspx.cs" Inherits="Custom.GooglePageSpeedTest" Async="true" %>

<asp:Content ID="Content7" ContentPlaceHolderID="plcContent" runat="server">
    <style>
        #notesheader {
            cursor: pointer;
        }

        .resultsheader {
            padding-top: 30px;
        }

        .message {
            color: red;
            padding: 20px 0;
        }

        .resultblock{
            float:left;
            padding: 0 50px;          
        }

    </style>
    <h2>Google Speed Test</h2>
    <div>This page uses the Google Page Speed Test API to evaluate page performance.</div>
    <div id="message" class="message" style="display: none;"></div>
    <h4 class="resultsheader" id="notesheader">Notes (click to expand)</h4>
    <div id="notes" class="results" style="display: none;">
        <ul>
            <li>You can find more information about the Google PageSpeed API <a href="https://developers.google.com/speed/docs/insights/v1/getting_started" target="_blank">here</a>.</li>
            <li>You must set your Google PageSpeed API key in the aspx file. (API_KEY)</li>
            <li>The Google Page Speed API can only access publically available pages.</li>
        </ul>
    </div>
    <h4 class="resultsheader">Page URL
    </h4>
    <div><%=strURL%></div>
    <div class="resultblock">
        <h4 class="resultsheader">Score</h4>
        <div id="score" class="results"></div>
    </div>

    <div class="resultblock">
        <h4 class="resultsheader">Resource Breakdown</h4>
        <div id="resourcebreakdown" class="results"></div>
    </div>
    <div class="resultblock">
        <h4 class="resultsheader">Suggestions</h4>
        <div id="suggestions" class="results"></div>
    </div>

    <script src="https://ajax.aspnetcdn.com/ajax/jquery/jquery-2.2.0.min.js"></script>

    <script>

        var msg;

        // Specify your actual API key here:
        var API_KEY = 'AIzaSyARSsClFYIVz1Xnni5YoVh6WK76pP6uqqg';

        // Specify the URL you want PageSpeed results for here:
        var URL_TO_GET_RESULTS_FOR = '<%=strURL%>';

        var API_URL = 'https://www.googleapis.com/pagespeedonline/v1/runPagespeed?';
        var CHART_API_URL = 'http://chart.apis.google.com/chart?';

        // Object that will hold the callbacks that process results from the
        // PageSpeed Insights API.
        var callbacks = {}

        // Invokes the PageSpeed Insights API. The response will contain
        // JavaScript that invokes our callback with the PageSpeed results.
        function runPagespeed() {
            var s = document.createElement('script');
            s.type = 'text/javascript';
            s.async = true;
            var query = [
              'url=' + URL_TO_GET_RESULTS_FOR,
              'callback=runPagespeedCallbacks',
              'key=' + API_KEY,
            ].join('&');
            s.src = API_URL + query;
            document.head.insertBefore(s, null);
        }

        // Our JSONP callback. Checks for errors, then invokes our callback handlers.
        function runPagespeedCallbacks(result) {
            if (result.error) {
                var errors = result.error.errors;
                for (var i = 0, len = errors.length; i < len; ++i) {
                    if (errors[i].reason == 'badRequest' && API_KEY == 'yourAPIKey') {
                        $('#message').html('<h4 style=\"color: red;\">Message</h4>Please specify your Google API key in the API_KEY variable.');
                        $("#message").slideDown();

                    } else {
                        $('#message').html('<h4 style=\"color: red;\">Message</h4>' + errors[i].message);
                        $("#message").slideDown();
                    }
                }
                return;
            }

            // Dispatch to each function on the callbacks object.
            for (var fn in callbacks) {
                var f = callbacks[fn];
                if (typeof f == 'function') {
                    callbacks[fn](result);
                }
            }
        }

        // Invoke the callback that fetches results. Async here so we're sure
        // to discover any callbacks registered below, but this can be
        // synchronous in your code.
        setTimeout(runPagespeed, 0);

        callbacks.displayPageSpeedScore = function (result) {
            var score = result.score;
            // Construct the query to send to the Google Chart Tools.
            var query = [
              'chtt=Page+Speed+score:+' + score,
              'chs=300x167',
              'cht=gom',
              'chd=t:' + score,
              'chxt=x,y',
              'chxl=0:|' + score,
            ].join('&');
            var i = document.createElement('img');
            i.src = CHART_API_URL + query;
            $('#score').html(i);
            //document.body.insertBefore(i, null);
        };

        callbacks.displayTopPageSpeedSuggestions = function (result) {
            var results = [];
            var ruleResults = result.formattedResults.ruleResults;
            for (var i in ruleResults) {
                var ruleResult = ruleResults[i];
                // Don't display lower-impact suggestions.
                if (ruleResult.ruleImpact < 3.0) continue;
                results.push({
                    name: ruleResult.localizedRuleName,
                    impact: ruleResult.ruleImpact
                });
            }
            results.sort(sortByImpact);
            var ul = document.createElement('ul');
            for (var i = 0, len = results.length; i < len; ++i) {
                var r = document.createElement('li');
                r.innerHTML = results[i].name;
                ul.insertBefore(r, null);
            }
            if (ul.hasChildNodes()) {
                //document.body.insertBefore(ul, null);
                $('#suggestions').html(ul);
            } else {
                var div = document.createElement('div');
                div.innerHTML = 'No high impact suggestions. Good job!';
                $('#suggestions').html(div);
            }
        };

        // Helper function that sorts results in order of impact.
        function sortByImpact(a, b) { return b.impact - a.impact; }

        var RESOURCE_TYPE_INFO = [
  { label: 'JavaScript', field: 'javascriptResponseBytes', color: 'e2192c' },
  { label: 'Images', field: 'imageResponseBytes', color: 'f3ed4a' },
  { label: 'CSS', field: 'cssResponseBytes', color: 'ff7008' },
  { label: 'HTML', field: 'htmlResponseBytes', color: '43c121' },
  { label: 'Flash', field: 'flashResponseBytes', color: 'f8ce44' },
  { label: 'Text', field: 'textResponseBytes', color: 'ad6bc5' },
  { label: 'Other', field: 'otherResponseBytes', color: '1051e8' },
        ];

        callbacks.displayResourceSizeBreakdown = function (result) {
            var stats = result.pageStats;
            var labels = [];
            var data = [];
            var colors = [];
            var totalBytes = 0;
            var largestSingleCategory = 0;
            for (var i = 0, len = RESOURCE_TYPE_INFO.length; i < len; ++i) {
                var label = RESOURCE_TYPE_INFO[i].label;
                var field = RESOURCE_TYPE_INFO[i].field;
                var color = RESOURCE_TYPE_INFO[i].color;
                if (field in stats) {
                    var val = Number(stats[field]);
                    totalBytes += val;
                    if (val > largestSingleCategory) largestSingleCategory = val;
                    labels.push(label);
                    data.push(val);
                    colors.push(color);
                }
            }
            // Construct the query to send to the Google Chart Tools.
            var query = [
              'chs=300x140',
              'cht=p3',
              'chts=' + ['000000', 16].join(','),
              'chco=' + colors.join('|'),
              'chd=t:' + data.join(','),
              'chdl=' + labels.join('|'),
              'chdls=000000,14',
              'chp=1.6',
              'chds=0,' + largestSingleCategory,
            ].join('&');
            var i = document.createElement('img');
            i.src = 'http://chart.apis.google.com/chart?' + query;
            $('#resourcebreakdown').html(i);

        };


        $(function () {
            $('#notesheader').click(function () {
                $("#notes").slideToggle();
            });
        });

    </script>

</asp:Content>
